/*
 *  InitialGuessFile.cc
 *  fico
 *
 *  Created by Jose H. Garcia on 8/9/06.
 *  Copyright 2006 NCAR/HAO. All rights reserved.
 *
 */


#include "InitialGuessFile.h"

using namespace CSAC;


InitialGuessFile::InitialGuessFile(const string &f) 
{ 
	_name = f; 
	_B.resize(0,0.0);
	_Inclination.resize(0,0.0);
	_Azimuth.resize(0,0.0);
	_Eta0.resize(0,0.0);
	_Damp.resize(0,0.0);
	_Dop.resize(0,0.0);
	_B0.resize(0,0.0);
	_B1.resize(0,0.0);
}

void 
InitialGuessFile::load_guess_at_pixel(int pos, MERLIN_Model &par)
{
	int min_pos;
	
	min_pos = _B.size() - 1;
	if ( pos > min_pos )
		throw string("At vector _B, the requested position for pixel initial guess is out of range");
	if(_B[pos] > 4000)
            par.magnetic_field.value=4000;
	else
            par.magnetic_field.value=_B[pos];
	
	min_pos = _Inclination.size() - 1;
	if ( pos > min_pos )
		throw string("At vector _Inclination, the requested position for pixel initial guess is out of range");
	par.inclination.value=_Inclination[pos] * Pi/180.;
	
	min_pos = _Azimuth.size() - 1;
	if ( pos > min_pos )
		throw string("At vector _Azimuth, the requested position for pixel initial guess is out of range");
	par.azimuth.value=_Azimuth[pos] * Pi/180.;
	
	min_pos = (_Eta0.size() - 1);
	if ( pos > min_pos )
		throw string("At vector _Eta0, the requested position for pixel initial guess is out of range");
	par.line_strength.value=_Eta0[pos];
	
	min_pos = _Dop.size() - 1; 
	if ( pos > min_pos )
		throw string("At vector _Dop, the requested position for pixel initial guess is out of range");
	par.doppler_width.value=_Dop[pos];
	
	min_pos = _Damp.size() - 1;
	if ( pos > min_pos )
		throw string("At vector _Damp, the requested position for pixel initial guess is out of range");
	par.damping.value=_Damp[pos]; 
	
	min_pos = _B0.size() - 1;
	if ( pos > min_pos )
		throw string("At vector _B0, the position for pixel initial guess is out of range");
	par.planck_function.value=_B0[pos];
	
	min_pos = _B1.size() - 1;
	if ( pos > min_pos  )
		throw string("At vector _B1, the requested position for pixel initial guess is out of range");
	par.planck_function_gradient.value=_B1[pos];
	
	
	// For DLSP data, the macro turbulence is a fix value of 1.114 Km/s
	// par.vmac.value = 1.114;
	// For HINODE the macroturbulence is 0.7083 km/sec (the proper value for the SP = 24.7935 mA FWHM)
	par.vmac.value = 0.7083;
	
	if (par.lines.size()  != 2)
		throw string("There are more atomic lines than the allowed for initialization in this code.");
	
	min_pos = _lines_shift[0].size() - 1;
	if ( pos > min_pos  )
		throw string("At vector 0 for the lines shift, the requested position for pixel initial guess is out of range");
	par.lines[0].wavelength_shift.value = _lines_shift[0][pos];
	
	min_pos = _lines_shift[1].size() - 1;
	if ( pos > min_pos  )
		throw string("At vector 1 for the lines shift, the requested position for pixel initial guess is out of range");
	par.lines[1].wavelength_shift.value = _lines_shift[1][pos];
	
	min_pos = _stray_light.size() - 1;
	if ( pos > min_pos  )
		throw string("At vector _stray_light, the requested position for pixel initial guess is out of range");
        par.stray_light.value = _stray_light[pos];
	
	min_pos = _stray_light_shift.size() - 1;
	if ( pos > min_pos  )
	  throw string("At vector _stray_light_shift, the requested position for pixel initial guess is out of range");
	par.stray_light_shift.value = _stray_light_shift[pos];
		
	par.set_n_total_free_parameters();
}


void 
InitialGuessFile::load_ruff_guess_at_pixel(int pos, MERLIN_Model &par)
{
	int min_pos;
	
	min_pos = _B.size() - 1;
	if ( pos > min_pos )
		throw string("At vector _B, the requested position for pixel initial guess is out of range");
	//if(_B[pos] > 3000)
	//  par.magnetic_field.value=3000;
	//else
	  par.magnetic_field.value=_ruff_B[pos];
	
	min_pos = _Inclination.size() - 1;
	if ( pos > min_pos )
		throw string("At vector _Inclination, the requested position for pixel initial guess is out of range");
	par.inclination.value=_Inclination[pos] * Pi/180.;
	
	min_pos = _Azimuth.size() - 1;
	if ( pos > min_pos )
		throw string("At vector _Azimuth, the requested position for pixel initial guess is out of range");
	par.azimuth.value=_Azimuth[pos] * Pi/180.;
	
	min_pos = (_Eta0.size() - 1);
	if ( pos > min_pos )
		throw string("At vector _Eta0, the requested position for pixel initial guess is out of range");
	par.line_strength.value=_Eta0[pos];
	
	min_pos = _Dop.size() - 1; 
	if ( pos > min_pos )
		throw string("At vector _Dop, the requested position for pixel initial guess is out of range");
	par.doppler_width.value=_Dop[pos];
	
	min_pos = _Damp.size() - 1;
	if ( pos > min_pos )
		throw string("At vector _Damp, the requested position for pixel initial guess is out of range");
	par.damping.value=_Damp[pos]; 
	
	min_pos = _B0.size() - 1;
	if ( pos > min_pos )
		throw string("At vector _B0, the position for pixel initial guess is out of range");
	par.planck_function.value=_B0[pos];
	
	min_pos = _B1.size() - 1;
	if ( pos > min_pos  )
		throw string("At vector _B1, the requested position for pixel initial guess is out of range");
	par.planck_function_gradient.value=_B1[pos];
	
	
	// For DLSP data, the macro turbulence is a fix value of 1.114 Km/s
	 par.vmac.value = 1.114;
	// For HINODE the macroturbulence is 0.7083 km/sec (the proper value for the SP = 24.7935 mA FWHM)
	//par.vmac.value = 0.7083;
	
	if (par.lines.size()  != 2)
		throw string("There are more atomic lines than the allowed for initialization in this code.");
	
	min_pos = _lines_shift[0].size() - 1;
	if ( pos > min_pos  )
		throw string("At vector 0 for the lines shift, the requested position for pixel initial guess is out of range");
	par.lines[0].wavelength_shift.value = _lines_shift[0][pos];
	
	min_pos = _lines_shift[1].size() - 1;
	if ( pos > min_pos  )
		throw string("At vector 1 for the lines shift, the requested position for pixel initial guess is out of range");
	par.lines[1].wavelength_shift.value = _lines_shift[1][pos];
	
	min_pos = _stray_light.size() - 1;
	if ( pos > min_pos  )
		throw string("At vector _stray_light, the requested position for pixel initial guess is out of range");
        par.stray_light.value = _stray_light[pos];
	
	min_pos = _stray_light_shift.size() - 1;
	if ( pos > min_pos  )
	  throw string("At vector _stray_light_shift, the requested position for pixel initial guess is out of range");
	par.stray_light_shift.value = _stray_light_shift[pos];
		
	par.set_n_total_free_parameters();
}


