#ifndef MERLIN_Plan_h_
#define MERLIN_Plan_h_ 1
 

// MERLIN Fundamental Inversion Code (FICO)
#include "MERLIN.h"
#include "MERLIN_Model.h"
#include "MERLIN_Range.h"


// Client specific classes
#include "CSACFile.h"


// Very Tiny XML Parser
#include "tinyxml.h"

using namespace CSAC;

///
class MERLIN_Plan_Exception
{
    string _what;
public:
    MERLIN_Plan_Exception(const char* filename, int fileline, const string &err) 
    {
        char error_line[32];
        snprintf(error_line,sizeof(error_line), "%i", fileline);
        string my_header = string(filename) + string(":") + string (error_line) + string(": ");
        _what = my_header + err;
    }
    string what() { return _what;}
};

typedef struct genetic_pars_
{
    int individuals;
    int generations;
} genetic_pars;

///
class MERLIN_Plan
{
    ///
    void planDEBUG(const string &message, const int & indentation_level);
    ///
    string get_xml_declaration_type(const int &t);
    ///
    void load_ranges_from_xml_object(TiXmlNode* pNode);
    ///
    void load_lines_from_xml_object(TiXmlNode* pNode);
    ///
    void load_stray_light_from_xml_object(TiXmlNode* pNode);
    ///
    void load_parameters_from_xml_object(TiXmlNode* pNode);
    ///
    void load_model_from_xml_object(TiXmlNode* pNode);
    ///
    void load_files_from_xml_object(TiXmlNode* pNode);
    ///
    void load_limits_from_xml_object(TiXmlNode* pNode);
    ///
    void load_weights_from_xml_object(TiXmlNode* pNode);
    ///
    void load_genetic_from_xml_object(TiXmlNode* pNode);
    ///
    void compute_smoooth_extension (vector <double> &data, int original, int desired);
public:
    ///
    vector<MERLIN_Range> parsed_ranges;
    ///
    bool include_profiles_in_output;
    ///
    string input_file;
    ///
    string guess_file;
    ///
    string output_file;
    ///
    string solver;
    ///
    int y_min;
    ///
    int y_max;
    ///
    double stokes_I_weight;
    ///
    double stokes_Q_weight;
    ///
    double stokes_U_weight;
    ///
    double stokes_V_weight;
    ///
    genetic_pars genetic;
    ///
    double polarization_threshold;
    ///
    MERLIN_Model model;
    ///
    MERLIN_Plan() : include_profiles_in_output(false){};
    ///
    void build_inversion_plan_from_xml_file( const char* pFilename);
};

#endif //  MERLIN_Plan_h_
