/* ============================================================================
 * Language: C++ 
 * File: MERLIN_AtomicLine.cc
 * Package Name: Milne Eddington gRid Linear Inversion Network (MERLIN).
 * Sub-package: Fundamental Inversion Code (FICO).
 *
 * Created by Jose Garcia <jgarcia@ucar.edu> on 11/11/05.
 *  
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * You can contact University Corporation for Atmospheric Research at
 * 3080 Center Green Drive, Boulder, CO 80301

 * (c) COPYRIGHT University Corporation for Atmostpheric Research 2004-2006
 * Please read the full copyright statement in the file COPYRIGHT_UCAR.
 *
 =========================================================================== */


#include <vector>
using std::vector;
#include <iostream>
using std::endl ;
using std::cout;

#include "MERLIN_AtomicLine.h"
using CSAC::MERLIN_AtomicLine;

void
MERLIN_AtomicLine::dump( ostream &strm ) const
{
    strm.precision(15);
    strm << endl << "        line:" << endl ;
    strm << "            Central wave = " << central_wav << endl ;
    strm << "            e_lower = " << e_lower<< endl ;
    strm << "            e_upper = " << e_upper<< endl ;
    strm << "            Relative strength = "<< relative_strength <<endl;
    strm << "            Relative speed of the wave = "<< wavelength_shift.value <<endl;
    strm << "            Relative speed of the wave is free? ";
    if( wavelength_shift.free)
        strm<<"true"<<endl;
    else
        strm<<"false"<<endl;
    strm<<"            "<<"Begin Zeeman components of the line: "<<endl;
    for(int i=0; i < comp.size(); i++)
    {
        strm<<"                  "<<"Strength = "<<comp[i].strength<<" "<<"Type = ";
        switch (comp[i].type)
        {
            case MERLIN_ZeemanComponent::PI:
                strm<<"PI ";
                break;
            case MERLIN_ZeemanComponent::SIGMA_RIGHT:
                strm<<"SIGMA_RIGHT ";
                break;
            case MERLIN_ZeemanComponent::SIGMA_LEFT:
                strm<<"SIGMA_LEFT ";
                break;
        }
        strm<<"Derivative = "<<comp[i].derivative<<endl;
    }
    strm<<"            "<<"End Zeeman components of the line."<<endl;
}




