/* ============================================================================
* Language: C++ 
* File: MERLIN_Chisq.h
* Package Name: Milne Eddington gRid Linear Inversion Network (MERLIN).
* Sub-package: Fundamental Inversion Code (FICO).
*
* Created by Jose Garcia <jgarcia@ucar.edu> on 11/11/05.
*  
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
* You can contact University Corporation for Atmospheric Research at
* 3080 Center Green Drive, Boulder, CO 80301

* (c) COPYRIGHT University Corporation for Atmostpheric Research 2004-2006
* Please read the full copyright statement in the file COPYRIGHT_UCAR.
*
=========================================================================== */

#ifndef MERLIN_Chisq_h_
#define MERLIN_Chisq_h_ 1

#include "MERLIN.h"
#include "MERLIN_MilneEddington.h"
#include "MERLIN_Profile.h"
#include "MERLIN_ModelCorrection.h"
namespace CSAC
{
    
    ///
    class MERLIN_Chisq
{
    double chisq,scale_factor;  
public:
  
    // SAG: Basic constructor
    MERLIN_Chisq(){chisq=0;scale_factor=0;}

    // SAG: Basic accessor methods etc.   
    double get_chisq() const {return chisq;}
    double get_scale_factor() const{return scale_factor;}
    void set_chisq(double val){chisq=val;}
    void set_scale_factor(double val){scale_factor=val;}    
    operator double() const {return chisq;}
    
    static MERLIN_Chisq compute_chisq(MERLIN_StokesProfile &observed, 
                                      MERLIN_StokesProfile &synthetic, 
                                      MERLIN_Model &guess, 
                                      MERLIN_StokesProfile *sigma,
                                      const double &normalization);
    static double compute_chisq_I(MERLIN_StokesProfile &observed, 
                                MERLIN_StokesProfile &synthetic, 
                                MERLIN_Model &guess, 
                                MERLIN_StokesProfile *sigma,
                                const double &normalization);
    static double compute_chisq_Q(MERLIN_StokesProfile &observed, 
                                MERLIN_StokesProfile &synthetic, 
                                MERLIN_Model &guess, 
                                MERLIN_StokesProfile *sigma,
                                const double &normalization);
    static double compute_chisq_U(MERLIN_StokesProfile &observed, 
                                MERLIN_StokesProfile &synthetic, 
                                MERLIN_Model &guess, 
                                MERLIN_StokesProfile *sigma,
                                const double &normalization);
    static double compute_chisq_V(MERLIN_StokesProfile &observed, 
                                MERLIN_StokesProfile &synthetic, 
                                MERLIN_Model &guess, 
                                MERLIN_StokesProfile *sigma,
                                const double &normalization);
    
    
};
} // end namespace CSAC

#endif // MERLIN_Chisq_h_
