/* ============================================================================
 * Language: C++ 
 * File: MERLIN_LScoupling.h
 * Package Name: Milne Eddington gRid Linear Inversion Network (MERLIN).
 * Sub-package: Fundamental Inversion Code (FICO).
 *
 * Created by Jose Garcia <jgarcia@ucar.edu> on 11/11/05.
 *  
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * You can contact University Corporation for Atmospheric Research at
 * 3080 Center Green Drive, Boulder, CO 80301

 * (c) COPYRIGHT University Corporation for Atmostpheric Research 2004-2006
 * Please read the full copyright statement in the file COPYRIGHT_UCAR.
 *
 =========================================================================== */

#ifndef MERLIN_LScoupling_h
#define MERLIN_LScoupling_h 1


#include "MERLIN_Object.h"

namespace CSAC
{
    /// Simple abstraction of the LS coupling for spectral lines.
    class MERLIN_LScoupling : public MERLIN_Object
    {
    public:
	/// Orbital angular momentum
        enum orbital_angular_momentum { S=0, P, D, F, G, H, I, K, L, M, N, O, Q };
	
    private:
	///
        unsigned int _Sval ;
	///
        MERLIN_LScoupling::orbital_angular_momentum _Lval ;
	///
        char _Lchar ;
	///
        double _Jval ;
	///
        unsigned int  _Jint ;
	///
        unsigned int	 _Jdec ;
	///
        void set_L() ;
	
    protected:
		
    public:
        ///
        MERLIN_LScoupling( ) {}
	///
	MERLIN_LScoupling( const char *coupling );
        ///
        MERLIN_LScoupling(const MERLIN_LScoupling &rhs)
        {
            _Sval=rhs._Sval ;
            _Lval=rhs._Lval ;
            _Lchar=rhs._Lchar ;
            _Jval=rhs._Jval ;
            _Jint=rhs._Jint ;
            _Jdec=rhs._Jdec ;
        }
  
	///
        virtual ~MERLIN_LScoupling() { }
	///
        unsigned int get_S() { return _Sval ; }
	///
        unsigned int get_2Splus1() { return ((2*_Sval)+1) ; }
	///
        MERLIN_LScoupling::orbital_angular_momentum get_L() { return _Lval ; }
	///
        char get_Lchar() { return _Lchar ; }
	///
        double get_J() { return _Jval ; }
	///
        unsigned int	 get_Jint() { return _Jint ; }
	///
        unsigned int	 get_Jdec() { return _Jdec ; }
	///
        virtual void dump( ostream &strm ) const 
        {
            strm << "MERLIN_LScoupling: (" << (void *)this << "): " ;
            strm << ((2*_Sval)+1) << _Lchar << _Jval ;
        }
	/// Overloaded = operator.
	MERLIN_LScoupling& operator=(const MERLIN_LScoupling &rhs)
        {
            if(this == &rhs)
                return (*this);
            _Sval=rhs._Sval ;
            _Lval=rhs._Lval ;
            _Lchar=rhs._Lchar ;
            _Jval=rhs._Jval ;
            _Jint=rhs._Jint ;
            _Jdec=rhs._Jdec ;
            return *this;
        }
  
  
    } ; // end class MERLIN_LScoupling

} // end namespace CSAC

#endif // MERLIN_LScoupling_h

