/* ============================================================================
 * Language: C++ 
 * File: MERLIN_Parameter.h
 * Package Name: Milne Eddington gRid Linear Inversion Network (MERLIN).
 * Sub-package: Fundamental Inversion Code (FICO).
 *
 * Created by Jose Garcia <jgarcia@ucar.edu> on 11/11/05.
 *  
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * You can contact University Corporation for Atmospheric Research at
 * 3080 Center Green Drive, Boulder, CO 80301

 * (c) COPYRIGHT University Corporation for Atmostpheric Research 2004-2006
 * Please read the full copyright statement in the file COPYRIGHT_UCAR.
 *
 =========================================================================== */

#ifndef MERLIN_Parameter_h_
#define MERLIN_Parameter_h_ 1

#include <iostream>
using std::endl;

#include "MERLIN.h"

#include "MERLIN_Object.h"
using CSAC::MERLIN_Object;

namespace CSAC
{
  
    /// \brief Simple data structure to hold together a parameter 
    /// and the fact that in an inversion such parameter may be considered free.
    class MERLIN_Parameter : public MERLIN_Object
    {
    public:
	/// value of this free parameter
	merlin_real value;
	/// this variable tells us is this parameter can be adjusted in the Least Square fitting process
	bool free;
	///
        merlin_real error;
        /// Default constructor
	MERLIN_Parameter() :
            value(0.0),
            free(true),
            error(0.0)
	{}
        // Copy constructor.
        MERLIN_Parameter(const MERLIN_Parameter &rhs)
        {
            value = rhs.value;
            free = rhs.free;
            error = rhs.error;
        }
	/// Destructor.         
	virtual ~MERLIN_Parameter() {};
	// Overloaded = operator.
	MERLIN_Parameter& operator=(MERLIN_Parameter const &rhs)
        {
            if(this == &rhs)
                return (*this);
            value = rhs.value;
            free = rhs.free;
            error = rhs.error;
            return *this;
        }
        /// Printer method
        virtual void dump( ostream &strm ) const 
        {
            strm<<"Parameter value = "<<value<<endl;
            strm<<"Parameter free = ";
            if (free)
                strm<<"TRUE"<<endl;
            else
                strm<<"FALSE"<<endl;
            strm<<"Parameter error = "<<error<<endl;
        }
    };

} // end namespace CSAC

#endif // MERLIN_Parameter_h_

