/* ============================================================================
 * Language: C++ 
 * File: MERLIN_Profile.h
 * Package Name: Milne Eddington gRid Linear Inversion Network (MERLIN).
 * Sub-package: Fundamental Inversion Code (FICO).
 *
 * Created by Jose Garcia <jgarcia@ucar.edu> on 11/11/05.
 *  
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * You can contact University Corporation for Atmospheric Research at
 * 3080 Center Green Drive, Boulder, CO 80301

 * (c) COPYRIGHT University Corporation for Atmostpheric Research 2004-2006
 * Please read the full copyright statement in the file COPYRIGHT_UCAR.
 *
 =========================================================================== */

#ifndef MERLIN_Profile_h_
#define MERLIN_Profile_h_ 1

#include <vector>
using std::vector;

#include <string>
using std::string;


#include "MERLIN_Object.h"
using CSAC::MERLIN_Object;

#include "MERLIN_StokesProfile.h"
using CSAC::MERLIN_StokesProfile;
#include "MERLIN_StokesProfileDerivatives.h"
using CSAC::MERLIN_StokesProfileDerivatives;

namespace CSAC
{
  
    /// Defines a Stokes profiles and its derivatives with respect of the free parameters in a Model Object.
    class MERLIN_Profile : public MERLIN_Object
    {
    public:
	/// Stokes profile.
        MERLIN_StokesProfile stokes;
	/// Derivatives of the Stokes profile with respect to the free parameters.
        MERLIN_StokesProfileDerivatives stokes_derivatives;
	//
	MERLIN_Profile() {};
	//
        virtual	~MERLIN_Profile() {};
	//
        virtual void dump( ostream &strm ) const;
	//
	void load_profile(const string &filename);
	// clear all contents
	void clear()
        {
            stokes.lambda.clear();
            stokes.I.clear();
            stokes.Q.clear();
            stokes.U.clear();
            stokes.V.clear();
            for (int j = 0; j < stokes_derivatives.I_dxdy.size(); j++)
            {
                stokes_derivatives.I_dxdy[j].clear();
                stokes_derivatives.Q_dxdy[j].clear();
                stokes_derivatives.U_dxdy[j].clear();
                stokes_derivatives.V_dxdy[j].clear();
            }
            stokes_derivatives.I_dxdy.clear();
            stokes_derivatives.Q_dxdy.clear();
            stokes_derivatives.U_dxdy.clear();
            stokes_derivatives.V_dxdy.clear();
            stokes_derivatives.order.clear();
        }
        ///
        bool match_size(const int &number_of_free_parameters, const int &number_of_wavelenghts);
        ///
        void resize(const int &number_of_free_parameters, const int &number_of_wavelenghts);
	/// dump contents of I, Q, U and V and lambda
	/// so they can be plottted in Matlab. If the user 
	/// supplies a set of string, the those strings are used for printing
	/// the names of I, Q, U and V.
	void print_stokes_vectors(ostream &oss, const char *lambda = "lambda", const char *I = "I", const char *Q = "Q", const char *U = "U", const char *V = "V")
        {
            stokes.print_stokes_vectors(oss, lambda, I, Q, U, V);
        }
  
    } ; 

} //end namespace CSAC

#endif // MERLIN_Profile_h_

