/* ============================================================================
 * Language: C++ 
 * File: MERLIN_StokesProfile.h
 * Package Name: Milne Eddington gRid Linear Inversion Network (MERLIN).
 * Sub-package: Fundamental Inversion Code (FICO).
 *
 * Created by Jose Garcia <jgarcia@ucar.edu> on 11/11/05.
 *  
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * You can contact University Corporation for Atmospheric Research at
 * 3080 Center Green Drive, Boulder, CO 80301

 * (c) COPYRIGHT University Corporation for Atmostpheric Research 2004-2006
 * Please read the full copyright statement in the file COPYRIGHT_UCAR.
 *
 =========================================================================== */

#include <vector>
using std::vector;

#include <iostream>
using std::endl;
using std::ostream;

#ifndef MERLIN_StokesProfile_h_
#define MERLIN_StokesProfile_h_ 1

namespace CSAC
{
  
    /// Simples structure to hold together the Stokes profile: I, Q, U and V.
    class MERLIN_StokesProfile
    {
    public:
        /// Wavelength for the elements in the profile.
	vector<double> lambda;
        /// Stokes I.
	vector<double> I;
        /// Stokes Q.
	vector<double> Q;
        /// Stokes U.
	vector<double> U;
        /// Stokes V.
	vector<double> V;
        ///
        void print_stokes_vectors(ostream &oss, const char *s_lambda = "lambda", const char *s_I = "I", const char *s_Q = "Q", const char *s_U = "U", const char *s_V = "V")
        {
            oss.precision(10);  
    
            oss << s_lambda << "=[";
            for(int g = 0; g < lambda.size(); g++)
            {
                oss << lambda[g];
                if (g < (lambda.size() - 1) )
                    oss << ", ";
            }
            oss << "];" << endl;  
    
            oss << s_I << "=[";
            for(int g = 0; g < I.size(); g++)
            {
                oss << I[g];
                if (g < ( I.size() - 1) )
                    oss << ", ";
            }
            oss << "];" << endl;
    
            oss << s_Q << "=[";
            for(int g = 0; g < Q.size(); g++)
            {
                oss << Q[g];
                if (g < (Q.size() - 1) )
                    oss << ", ";
            }
            oss << "];" << endl;
    
            oss << s_U << "=[";
            for(int g = 0; g < U.size(); g++)
            {
                oss << U[g];
                if (g < (U.size() - 1) )
                    oss << ", ";
            }
            oss << "];" << endl;
    
            oss << s_V << "=[";
            for(int g = 0; g < V.size(); g++)
            {
                oss << V[g];
                if (g < (V.size() - 1) )
                    oss << ", ";
            }
            oss << "];" << endl;
        }
  
    };

} // end namespace CSAC

#endif // MERLIN_StokesProfile_h_
