/* ============================================================================
* Language: C++ 
* File: MERLIN_SweepOperator.h
* Package Name: Milne Eddington gRid Linear Inversion Network (MERLIN).
* Sub-package: Fundamental Inversion Code (FICO).
*
* Created by Jose Garcia <jgarcia@ucar.edu> on 05/15/07.
*  
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*
* You can contact University Corporation for Atmospheric Research at
* 3080 Center Green Drive, Boulder, CO 80301

* (c) COPYRIGHT University Corporation for Atmostpheric Research 2004-2006
* Please read the full copyright statement in the file COPYRIGHT_UCAR.
*
=========================================================================== */

#ifndef MERLIN_SweepOperator_h_
#define MERLIN_SweepOperator_h_ 1

#include <string.h>
#include <iostream>
using namespace std;

namespace CSAC
{
    
///
class MERLIN_SweepOperator
{
public:
    ///
    static void sweep (double ** A, int * used, const int &dimension, const int &total_number_of_sweep_operations)
{
        if (dimension <= 1)
            return;
        if (total_number_of_sweep_operations > dimension)
            return;
        if (!A)
            return;
        if (!used)
            return;
        
        for (int t = 0; t < dimension; t++)
            used[t]=0;
        
        double pivot;
        double cache;
        
        for (int k = 0; k < total_number_of_sweep_operations; k++)
        {
            if ( A[k][k] != 0)
            {
                
                used[k] = 1;
                pivot = 1 / A[k][k];
                // Sweep elements not in the row 
                // or column of the pivot
                for (int i = 0; i < dimension; i++)
                {
                    if (i != k)
                    {
                        cache  = A[i][k] * pivot;
                        for (int j = 0; j < dimension; j++)
                        {
                            
                            if (j != k)
                            {
                                A[i][j] = A[i][j] - (cache * A[k][j]);
                            }
                        }
                    }
                }
                // Sweep all elements in the kth row and column
                for (int y = 0; y < dimension; y++)
                {
                    // row element
                    A[k][y] = A[k][y] * pivot;
                    // column element
                    A[y][k] = A[y][k] * pivot;
                }
                A[k][k] = - pivot;
            }
        }
}

};

} //end namespace CSAC


#endif // MERLIN_SweepOperator_h_
