/*******************************************************************
 * This code is based on code by Kai Hock (2008),
 * Kai Hock, University of Liverpool, UK
 * Distributed with permission.
 *
 * *
 * *  This is a wrapper for the FFT function four1 in Numerical Recipes
 * *  It follows the argument specifications.
 * *
 * *  NB: 
 * *      1. size of data is 2*nn, not nn
 * *      2. range of data is 1 to 2*nn. NOT 0 to 2*nn-1
 * *      3. if calling with data[0..2*nn-1], use data-1 in input argument
 * *         i.e. four1_FFTW(data-1, nn, isign);
 * *
 * *
 * * ** add these to the right places if calling with external plans:
 * *
 * *     #include <fftw3.h>               ** header
 * *
 * *
 * *     fftw_plan p1_FFTW;               **  global variables to store FFTW wisdom
 * *     fftw_plan p2_FFTW;
 * *
 * *     extern fftw_plan     p1_FFTW;    ** header of function file
 * *     extern fftw_plan     p2_FFTW;
 * *
 * *     fftw_destroy_plan(p1_FFTW);      ** end of main program
 * *     fftw_destroy_plan(p2_FFTW);
 * *
 * *  **  compile and link with
 * *
 * *     gcc -o main main.c four1_FFTW.c -L./ -llibfftw3-3 -lm
 * *
 * *  **  library files to add to directory
 * *
 * *       libfftw3-3.a,  fftw3.h
 * ********************************************************************/
#include <math.h>
#include <fftw3.h>

void four1_FFTW(double data[], unsigned long nn, int isign) {
	int n = nn;
	int i;
	/* Allocate memory */
	fftw_complex* input = fftw_malloc(sizeof(fftw_complex) * n);
	fftw_complex* output = fftw_malloc(sizeof(fftw_complex) * n);
	// FFTW Plan
	fftw_plan plan;
	if(isign == 1) plan = fftw_plan_dft_1d(n, input, output, FFTW_FORWARD, FFTW_MEASURE);
	if(isign == -1) plan = fftw_plan_dft_1d(n, input, output, FFTW_BACKWARD, FFTW_MEASURE);
	/* FFT: insert - sign for imag part because 
	 Num Rec FFT  uses exp(+i*2*pi*m*n/N) whereas
	 FFTW uses exp(-i*2*pi*m*n/N) */
	for(i = 0; i < n; i++) {
		input[i][0] =  data[2*i+1];
		input[i][1] = -data[2*i+2];
	}  
	fftw_execute(plan);   /* FFT */
	for(i = 0; i < n; i++) {
		data[2*i+1] =  output[i][0];
		data[2*i+2] = -output[i][1];
	}    
	/* Destroy plans */ 
	fftw_destroy_plan(plan);
	/* Free memory */
	fftw_free(input);
	fftw_free(output);
}
