	subroutine rufffld
     .	( np, obsi, obsv
     .	, limblu, ceni, limred
     .	, cct, dlamh, disper, dircsn
     .	, ivcen, iblu, imid, ired, dirfld
     .	)
!
!	subroutine: rufffld
!
!	purpose:  Find ruff magnetic field strength.
!
!	author:  paul@ncar  (revised 2/97)
!
!	input:
!		  np	- dimension of input data arrays.
!	      obsi(np)	- observed i-profile.
!	      obsv(np)	- observed v-profile.
!
!		limblu  - lower limit of band pass, pixels (integer).
!		ceni	- approximate spectra line center, pixels (real).
!		limred  - upper limit of band pass, pixels (integer).
!
!		cct	- continuum intensity.
!		dlamh	- factor used to determine field strength
!			  based on splitting half width, gauss/A.
!		disper	- pixel to pixel dispersion, mA.
!		dircsn	- cosine of field angle from line of sight.
!	output:
!		ivcen	- approximate center of v-profile, pixel.
!		iblu	- low pixel where splitting found, otherwise 0.
!		imid	- local minimum or maximum nearest center
!			  in i-profile, pixel.
!		ired	- high pixel where splitting found, otherwise 0.
!		dirfld	- ruff field strength, gauss.
!			  If splitting was found dirfld is returned negative.
!			  If moment method used dirfld is returned positive.
!
!------------------------------------------------------------------------------
	integer w

				    !Data arrays.
	dimension obsi(np), obsv(np)

				    !Temporary storage.
	parameter( itmp = 2048 )
	dimension vec1(itmp), vec2(itmp)
	if( itmp .lt. np ) then
		write(6,'(''a.rufffld.f: itmp dimension to small'')')
		stop 'a.rufffld.f: itmp dimension to small'
	endif

	jcen = nint( ceni )
				    !Find local minimum or maximum in
				    !i-profile nearest center
	do 300 ipx = 1,min(jcen-limblu,limred-jcen)
		call findmx(obsi,jcen-ipx,jcen+ipx,v1,v2,imx,imm)
		if( imx.ne.jcen-ipx .and. imx.ne.jcen+ipx ) then
			imid = imx
			goto 400
		endif
		if( imm.ne.jcen-ipx .and. imm.ne.jcen+ipx ) then
			imid = imm
			goto 400
		endif
300	continue
	imid = 0
400	continue
				    !Find mimimu and maximum of v-profile.
	call findmx(obsv,limblu,limred,v1,v2,imx,imm)

				    !Center of v-profile.
	ivcen = (imx+imm)/2
				    !Look for minimum in i-profile near
				    !maximun in v-profile.
	ks1 = iabs(imx-imm)*3/8
	ilft = max(limblu,imx-ks1)
	irgt = max(ilft,min(limred,imx+ks1))
	call findmx(obsi,ilft,irgt,v1,v2,i1,ja)

				    !Look for minimum in i-profile near
				    !minimum in v-profile.
	jlft = max(limblu,imm-ks1)
	jrgt = max(jlft,min(limred,imm+ks1))
	call findmx(obsi,jlft,jrgt,v1,v2,i1,jb)

				    !Check if splitting was found.
	if(ja.ne.ilft .and. ja.ne.irgt) then
		if(jb.ne.jlft .and. jb.ne.jrgt) then

				    !Set field strength from splitting.
				    !Flag splitting found with negative.
			iblu = min(ja,jb)
			ired = max(ja,jb)
			dirfld = -(ired-iblu)/2.*dlamh*disper/1000.
		return
		endif
	endif
				    !Use first moment of v-profile to get
				    !longitudinal field in case where
				    !splitting is not available
				    !(See Rees and Semel 1979, A+A 74,1)

				    !Find the magnetic splitting from the
				    !first moment of the V-stokes profile
				    !with wavelength from line center jcen
				    !vmom =  first moment (in wavelength steps)

	do 10 w = limblu,limred
		vec1(w) = cct-obsi(w)
		vec2(w) = obsv(w)*(w-jcen)
10	continue

	aint = 0.
	do 20 w = limblu,limred
		aint = aint+vec1(w)
20	continue

	vmom = 0.
	do 60 w = limblu,limred
		vmom = vmom+vec2(w)
60	continue

	vmom = abs(vmom/aint)

	dirfld = abs( vmom*disper/dircsn*dlamh/1000. )

	iblu = 0
	ired = 0

        return
        end
